@@ -111,13 +111,15 @@ class LVMTemplateForm(NetBoxModelForm):
                                                       options=self.cleaned_data['fs_options'])
 
         linux_device = LinuxDevice.objects.create(device=device_name, type='efi')
-        partition = Partition.objects.create(drive=self.cleaned_data['drive'], device=linux_device, size=self.cleaned_data['drive'], type='Linux LVM')
+        partition = Partition.objects.create(drive=self.cleaned_data['drive'], device=linux_device,
+                                             size=self.cleaned_data['size'], type='Linux LVM')
 
         volume_group = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
         PhysicalVolume.objects.create(device=linux_device, vg=volume_group)
 
         # Add linux_device for lvm
-        linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home', type=self.cleaned_data['fs_type'])
+        linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home',
+                                                         type=self.cleaned_data['fs_type'])
         self.instance.vg = volume_group
         self.instance.size = self.cleaned_data['size']
         self.instance.device = linux_device_mapper
