@@ -1,9 +1,6 @@
-import django_tables2 as tables
-
 from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
-    ActionsColumn,
 )
 
 from netbox_storage.models import VolumeGroup
@@ -13,10 +10,6 @@ class VolumeGroupTable(NetBoxTable):
     """Table for displaying VolumeGroup objects."""
 
     pk = ToggleColumn()
-    vg_name = tables.Column(
-        linkify=True,
-        verbose_name="Volume Group Name"
-    )
 
     class Meta(NetBoxTable.Meta):
         model = VolumeGroup
@@ -27,5 +20,5 @@ class VolumeGroupTable(NetBoxTable):
         )
         default_columns = (
             "vg_name",
-            "description"
+            "description",
         )
