@@ -2,12 +2,11 @@ from netbox.views import generic
 
 from netbox_storage.filters import PhysicalVolumeFilter
 from netbox_storage.forms import (
-    PhysicalVolumeImportForm,
+  #  PhysicalVolumeImportForm,
     PhysicalVolumeFilterForm,
     PhysicalVolumeForm,
-    PhysicalVolumeBulkEditForm
+ #   PhysicalVolumeBulkEditForm
 )
-
 from netbox_storage.models import PhysicalVolume
 from netbox_storage.tables import PhysicalVolumeTable
 
@@ -20,29 +19,26 @@ class PhysicalVolumeListView(generic.ObjectListView):
 
 
 class PhysicalVolumeView(generic.ObjectView):
-    """Display PhysicalVolume details"""
-
     queryset = PhysicalVolume.objects.all()
 
 
 class PhysicalVolumeEditView(generic.ObjectEditView):
-    """View for editing a PhysicalVolume instance."""
-
     queryset = PhysicalVolume.objects.all()
     form = PhysicalVolumeForm
-    default_return_url = "plugins:netbox_storage:physicalvolume_list"
+    default_return_url = "plugins:netbox_storage:PhysicalVolume_list"
 
 
 class PhysicalVolumeDeleteView(generic.ObjectDeleteView):
     queryset = PhysicalVolume.objects.all()
-    default_return_url = "plugins:netbox_storage:physicalvolume_list"
+    default_return_url = "plugins:netbox_storage:PhysicalVolume_list"
 
 
+"""
 class PhysicalVolumeBulkImportView(generic.BulkImportView):
     queryset = PhysicalVolume.objects.all()
     model_form = PhysicalVolumeImportForm
     table = PhysicalVolumeTable
-    default_return_url = "plugins:netbox_storage:physicalvolume_list"
+    default_return_url = "plugins:netbox_storage:PhysicalVolume_list"
 
 
 class PhysicalVolumeBulkEditView(generic.BulkEditView):
@@ -55,3 +51,4 @@ class PhysicalVolumeBulkEditView(generic.BulkEditView):
 class PhysicalVolumeBulkDeleteView(generic.BulkDeleteView):
     queryset = PhysicalVolume.objects.all()
     table = PhysicalVolumeTable
+"""
\ No newline at end of file
